%define anolis_release 3

Name:		autogen
Version:	5.18.16
Release:	%{anolis_release}%{?dist}
Summary:	Automated text file generator
License:	GPLv3+
URL:		http://www.gnu.org/software/%{name}/
Source0:	ftp://ftp.gnu.org/gnu/%{name}/rel%{version}/%{name}-%{version}.tar.xz

Patch1:         0001-guile-version.patch
Patch2:         0002-remove-guile-version-check.patch
Patch1000:      1000-fix-dangle-pointer.patch

Requires:	%{name}-libopts = %{version}-%{release}

BuildRequires: gcc libtool make chrpath sed
BuildRequires: perl-generators perl(Carp) perl(constant) perl(Exporter) perl(File::Basename)
BuildRequires: perl(lib) perl(List::Util) perl(strict) perl(Text::ParseWords) perl(warnings)
BuildRequires: guile-devel libxml2-devel gmp-devel gc-devel

%description
AutoGen is a tool designed to simplify the creation and maintenance of
programs that contain large amounts of repetitious text. It is especially
valuable in programs that have several blocks of text that must be kept
synchronised. AutoGen will accept either its own definition format, or XML
files as definition input, in addition to CGI data (for producing dynamic
HTML) and traditional AutoGen definitions.

%package libopts
Summary: Automated option processing library based on %{name}
License: LGPLv3+

%description libopts
Libopts is very powerful command line option parser consisting of a set of
AutoGen templates and a run time library that nearly eliminates the hassle of
parsing and documenting command line options.

%package libopts-devel
Summary: Development files for libopts
License: LGPLv3+

Requires: automake %{name} = %{version}-%{release} %{name}-libopts = %{version}-%{release} pkgconfig

%description libopts-devel
This package contains development files for libopts.

%package doc
Summary: Documentation files for %{name}
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -n %{name}-%{version} -p1

# Disable failing test
sed -i 's|errors.test||' autoopts/test/Makefile.in

%build
# Static libraries are needed to run test-suite.
export CFLAGS="$RPM_OPT_FLAGS -Wno-implicit-fallthrough -Wno-format-overflow \
		-Wno-format-truncation"
%configure

# Omit unused direct shared library dependencies.
sed --in-place --expression 's! -shared ! -Wl,--as-needed\0!g' ./libtool

%make_build

%check
make check

%install
make install INSTALL="%{__install} -p" DESTDIR=%{buildroot}
find %{buildroot} -type f -name "*.la" -delete
find %{buildroot} -type f -name "*.a" -delete

# Remove time stamps from generated devel man pages to avoid multilib conflicts
sed -i 's|\(It has been AutoGen-ed\).*.\(by AutoGen\)|\1 \2|' \
	%{buildroot}%{_mandir}/man3/*.3

chrpath --delete %{buildroot}%{_bindir}/{columns,getdefs,%{name},xml2ag}
chrpath --delete %{buildroot}%{_libdir}/lib*.so.*

rm -f %{buildroot}%{_infodir}/dir

%generate_compatibility_deps

%files
%license COPYING
%license pkg/libopts/COPYING.gplv3
%dir %{abidir}
%{abidir}/%{name}-option.list
%{abidir}/columns-option.list
%{abidir}/xml2ag-option.list
%{_bindir}/columns
%{_bindir}/getdefs
%{_bindir}/%{name}
%{_bindir}/xml2ag
%{_infodir}/%{name}.info*.*
%{_mandir}/man1/%{name}.1.*
%{_mandir}/man1/columns.1.*
%{_mandir}/man1/getdefs.1.*
%{_mandir}/man1/xml2ag.1.*
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*

%dir %{_includedir}/autoopts
%{_includedir}/autoopts/options.h
%{_includedir}/autoopts/usage-txt.h

%files libopts
%license pkg/libopts/COPYING.mbsd
%license pkg/libopts/COPYING.lgplv3
%{_libdir}/libopts.so.25*

%files libopts-devel
%{_bindir}/autoopts-config
%{abidir}/autoopts-config-option.list
%{_datadir}/aclocal/autoopts.m4
%{_libdir}/libopts.so
%{abidir}/libopts.dump
%{_libdir}/pkgconfig/autoopts.pc
%{_mandir}/man1/autoopts-config.1.*
%{_mandir}/man3/*

%files doc
%doc AUTHORS ChangeLog NEWS README THANKS TODO

%changelog
* Mon Apr 10 2023 Jing Zhang <renyu.zj@linux.alibaba.com> - 5.18.16-3
- Refact spec

* Fri Jan 13 2023 yuanhui <yuanhui@linux.alibaba.com> - 5.18.16-2
- add doc package

* Fri Apr 22 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 5.18.16-1
- init from upstream
- compat with guile-3.0 and fix build error
